from setuptools import setup

setup(name='phasepersist',
      version='0.1',
      description='Load and save python stuff in pickle files.',
      url='http://github.com/phasemix/phasepersist',
      author='Roberto Allende',
      author_email='rallende@gmail.com',
      license='Apache 2.0',
      packages=['phasepersist'],
      zip_safe=False)